<?php
/*
Plugin Name: No Layout Posts
Description: This plugin creates a new post-type which will automatically pick a template file with no layout (no header, no footer, no wrapping divs). A post of this type will so display only the post content and then you can easily embed it on another site using an iframe. You can also set the Body colour, and the container width, with two custom fields within the post editor.
Author: Andrea Piccart
Version: 1.0.0
Author URI: http://www.bespokewebdeveloper.com
*/

/**
 * Block direct access to this file
 */
if ( !defined('ABSPATH') ) {
	die('-1');
}

/**
 * REGISTER THE CUSTOM POST TYPE
 */
add_action( 'init', 'no_layout_post_init' );
function no_layout_post_init() {
	$labels = array(
		'name'               => __( 'No Layout Posts' ),
		'singular_name'      => __( 'No Layout Post' ),
		'menu_name'          => __( 'No Layout Posts' ),
		'name_admin_bar'     => __( 'No Layout Post' ),
		'add_new'            => __( 'Add New' ),
		'add_new_item'       => __( 'Add No Layout Post' ),
		'new_item'           => __( 'New No Layout Post' ),
		'edit_item'          => __( 'Edit Post' ),
		'view_item'          => __( 'View Post' ),
		'all_items'          => __( 'All No Layout Posts' ),
		'search_items'       => __( 'Search Posts' ),
		'parent_item_colon'  => __( 'Parent Post:' ),
		'not_found'          => __( 'No Posts found.' ),
		'not_found_in_trash' => __( 'No Posts found in Trash.' )
	);

	$args = array(
		'labels'             => $labels,
		'public'             => true,
		'publicly_queryable' => true,
		'exclude_from_search'=> true,
		'show_ui'            => true,
		'show_in_menu'       => true,
		'show_in_nav_menu'   => false,
		'query_var'          => true,
		'rewrite'            => array( 'slug' => 'embed' ),
		'capability_type'    => 'post',
		'has_archive'        => false,
		'hierarchical'       => false,
		'menu_position'      => null,
		'supports'           => array( 'title', 'editor' ),
	);

	register_post_type( 'no_layout_post', $args );
}


/***** META FIELDS *****/

/**
 * Add Meta field box into no_layout_posts
 */ 
add_action( 'add_meta_boxes', 'no_layout_add_meta_box' );
function no_layout_add_meta_box() {
	add_meta_box(
			'no_layout_meta_fields',
			__( 'Layout Options' ),
			'no_layout_meta_box_callback',
			'no_layout_post'
	);

}

/**
 * Prints the box content.
 * 
 * @param WP_Post $post The object for the current post/page.
 */
function no_layout_meta_box_callback( $post ) {

	// Add an nonce field so we can check for it later.
	wp_nonce_field( 'no_layout_meta_box', 'no_layout_meta_box_nonce' );

	/*
	 * Use get_post_meta() to retrieve an existing value
	 * from the database and use the value for the form.
	 */
	$body_colour = get_post_meta( $post->ID, 'no_layout_body_colour', true );
	$content_width = get_post_meta( $post->ID, 'no_layout_content_width', true );
	
	/* Print out the fields */
	// body colour field
	echo '<p>';
	echo '<label for="no_layout_body_colour">';
	_e( 'Background Colour for the Page Body' );
	echo '</label> ';
	echo '<input type="text" id="no_layout_body_colour" name="no_layout_body_colour" value="' . esc_attr( $body_colour ) . '" size="10" />';
	echo '</p>';
	// content width field
	echo '<p>';
	echo '<label for="no_layout_content_width">';
	_e( 'width for the post content container div' );
	echo '</label> ';
	echo '<input type="text" id="no_layout_content_width" name="no_layout_content_width" value="' . esc_attr( $content_width ) . '" size="5" /> must add px or &#37;';
	echo '</p>';
}

/**
 * When the post is saved, saves our custom data.
 *
 * @param int $post_id The ID of the post being saved.
 */
add_action( 'save_post', 'no_layout_save_meta_box_data' );
function no_layout_save_meta_box_data( $post_id ) {
	/*
	 * We need to verify this came from our screen and with proper authorization,
	 * because the save_post action can be triggered at other times.
	 */

	// Check if our nonce is set.
	if ( ! isset( $_POST['no_layout_meta_box_nonce'] ) ) {
		return;
	}
	// Verify that the nonce is valid.
	if ( ! wp_verify_nonce( $_POST['no_layout_meta_box_nonce'], 'no_layout_meta_box' ) ) {
		return;
	}
	// If this is an autosave, our form has not been submitted, so we don't want to do anything.
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Check the user's permissions.
	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {

		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return;
		}
	} else {
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}
	}

	/* OK, it's safe for us to save the data now. */
	
	// if body colour is set
	if ( isset( $_POST['no_layout_body_colour'] ) ) {
		// Update the meta field in the database.
		update_post_meta( $post_id, 'no_layout_body_colour', $_POST['no_layout_body_colour'] );			
	}
	
	// if content width is set
	if ( isset( $_POST['no_layout_content_width'] ) ) {
		// Update the meta field in the database.
		update_post_meta( $post_id, 'no_layout_content_width', $_POST['no_layout_content_width'] );			
	}
	
}



/**** SET THE POST TYPE TO USE OUR TEMPLATE FILE ****/
// we hook the template include function and we first check for a template file within the theme, otherwise use our default

add_filter( 'template_include', 'no_layout_post_template', 99 );
function no_layout_post_template( $template ) {
	// store vars
	global $wp;
	$plugindir = dirname( __FILE__ );
	$templatefilename = 'single-no-layout.php';
	// check if it's a no_layout_post
	if ( $wp->query_vars["post_type"] == 'no_layout_post' ){
		// check if there is a specific file into the theme folder
		if (file_exists(TEMPLATEPATH . '/' . $templatefilename)) {
            $return_template = TEMPLATEPATH . '/' . $templatefilename;
        } else {
			// if there isn't, use our default
            $return_template = $plugindir . '/templatefiles/' . $templatefilename;
        }
		// output the template
		return $return_template;
		
	}
	// if this is another post type, simply return the template that was set before the hook
	return $template;

}


?>